@@ -10,7 +10,7 @@ if os.path.isdir(DIR):
 
 import unittest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import RPCProxy, CONTEXT, SOCK, test_view
+from trytond.tests.test_tryton import test_view
 
 
 class GoogleMapsTestCase(unittest.TestCase):
@@ -28,11 +28,10 @@ class GoogleMapsTestCase(unittest.TestCase):
         self.assertRaises(Exception, test_view('google_maps'))
 
 def suite():
-    return unittest.TestLoader().loadTestsFromTestCase(GoogleMapsTestCase)
+    suite = trytond.tests.test_tryton.suite()
+    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
+        GoogleMapsTestCase))
+    return suite
 
 if __name__ == '__main__':
-    suiteTrytond = trytond.tests.test_tryton.suite()
-    suiteGoogleMaps = suite()
-    alltests = unittest.TestSuite([suiteTrytond, suiteGoogleMaps])
-    unittest.TextTestRunner(verbosity=2).run(alltests)
-    SOCK.disconnect()
+    unittest.TextTestRunner(verbosity=2).run(suite())
